@@ -16,14 +16,14 @@ impl Default for MyApp {
 
 impl epi::App for MyApp {
     fn name(&self) -> &str {
-        "My Egui App"
+        "My egui App"
     }
 
     fn update(&mut self, ctx: &egui::CtxRef, frame: &mut epi::Frame<'_>) {
         let Self { name, age } = self;
 
         egui::CentralPanel::default().show(ctx, |ui| {
-            ui.heading("My Egui Application");
+            ui.heading("My egui Application");
             ui.horizontal(|ui| {
                 ui.label("Your name: ");
                 ui.text_edit_singleline(name);
